@@ -30,7 +30,7 @@ package PDL::Lvalue;
 
 # list of functions that can be used as lvalue subs
 # extend as necessary
-my @funcs = qw/slice mslice nslice index where px diagonal clump
+my @funcs = qw/slice mslice nslice nslice_if_pdl index where px diagonal clump
   dummy index2d dice dice_axis xchg mv flat sever polyfillv range rangeb 
   indexND indexNDb reshape/;
 
